# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: turkish_morphology/analysis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='turkish_morphology/analysis.proto',
  package='turkish_morphology',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=b'\n!turkish_morphology/analysis.proto\x12\x12turkish_morphology\"\x18\n\x04Root\x12\x10\n\x08morpheme\x18\x01 \x01(\t\"*\n\x07\x46\x65\x61ture\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"L\n\x05\x41\x66\x66ix\x12,\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x1b.turkish_morphology.Feature\x12\x15\n\rmeta_morpheme\x18\x02 \x01(\t\"\xb6\x01\n\x11InflectionalGroup\x12\x0b\n\x03pos\x18\x01 \x01(\t\x12&\n\x04root\x18\x02 \x01(\x0b\x32\x18.turkish_morphology.Root\x12-\n\nderivation\x18\x03 \x01(\x0b\x32\x19.turkish_morphology.Affix\x12-\n\ninflection\x18\x04 \x03(\x0b\x32\x19.turkish_morphology.Affix\x12\x0e\n\x06proper\x18\x05 \x01(\x08\"=\n\x08\x41nalysis\x12\x31\n\x02ig\x18\x01 \x03(\x0b\x32%.turkish_morphology.InflectionalGroup'
)




_ROOT = _descriptor.Descriptor(
  name='Root',
  full_name='turkish_morphology.Root',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='morpheme', full_name='turkish_morphology.Root.morpheme', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=81,
)


_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='turkish_morphology.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='turkish_morphology.Feature.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='turkish_morphology.Feature.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=125,
)


_AFFIX = _descriptor.Descriptor(
  name='Affix',
  full_name='turkish_morphology.Affix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='turkish_morphology.Affix.feature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta_morpheme', full_name='turkish_morphology.Affix.meta_morpheme', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=203,
)


_INFLECTIONALGROUP = _descriptor.Descriptor(
  name='InflectionalGroup',
  full_name='turkish_morphology.InflectionalGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pos', full_name='turkish_morphology.InflectionalGroup.pos', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root', full_name='turkish_morphology.InflectionalGroup.root', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='derivation', full_name='turkish_morphology.InflectionalGroup.derivation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inflection', full_name='turkish_morphology.InflectionalGroup.inflection', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proper', full_name='turkish_morphology.InflectionalGroup.proper', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=388,
)


_ANALYSIS = _descriptor.Descriptor(
  name='Analysis',
  full_name='turkish_morphology.Analysis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ig', full_name='turkish_morphology.Analysis.ig', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=451,
)

_AFFIX.fields_by_name['feature'].message_type = _FEATURE
_INFLECTIONALGROUP.fields_by_name['root'].message_type = _ROOT
_INFLECTIONALGROUP.fields_by_name['derivation'].message_type = _AFFIX
_INFLECTIONALGROUP.fields_by_name['inflection'].message_type = _AFFIX
_ANALYSIS.fields_by_name['ig'].message_type = _INFLECTIONALGROUP
DESCRIPTOR.message_types_by_name['Root'] = _ROOT
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['Affix'] = _AFFIX
DESCRIPTOR.message_types_by_name['InflectionalGroup'] = _INFLECTIONALGROUP
DESCRIPTOR.message_types_by_name['Analysis'] = _ANALYSIS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Root = _reflection.GeneratedProtocolMessageType('Root', (_message.Message,), {
  'DESCRIPTOR' : _ROOT,
  '__module__' : 'turkish_morphology.analysis_pb2'
  # @@protoc_insertion_point(class_scope:turkish_morphology.Root)
  })
_sym_db.RegisterMessage(Root)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'turkish_morphology.analysis_pb2'
  # @@protoc_insertion_point(class_scope:turkish_morphology.Feature)
  })
_sym_db.RegisterMessage(Feature)

Affix = _reflection.GeneratedProtocolMessageType('Affix', (_message.Message,), {
  'DESCRIPTOR' : _AFFIX,
  '__module__' : 'turkish_morphology.analysis_pb2'
  # @@protoc_insertion_point(class_scope:turkish_morphology.Affix)
  })
_sym_db.RegisterMessage(Affix)

InflectionalGroup = _reflection.GeneratedProtocolMessageType('InflectionalGroup', (_message.Message,), {
  'DESCRIPTOR' : _INFLECTIONALGROUP,
  '__module__' : 'turkish_morphology.analysis_pb2'
  # @@protoc_insertion_point(class_scope:turkish_morphology.InflectionalGroup)
  })
_sym_db.RegisterMessage(InflectionalGroup)

Analysis = _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSIS,
  '__module__' : 'turkish_morphology.analysis_pb2'
  # @@protoc_insertion_point(class_scope:turkish_morphology.Analysis)
  })
_sym_db.RegisterMessage(Analysis)


# @@protoc_insertion_point(module_scope)
